package envoy.server.processors;

import java.io.IOException;

import envoy.data.IdGenerator;
import envoy.event.IdGeneratorRequest;
import envoy.server.ObjectProcessor;
import envoy.server.data.ConfigItem;
import envoy.server.database.PersistenceManager;
import envoy.server.net.ObjectWriteProxy;

/**
 * Project: <strong>envoy-server-standalone</strong><br>
 * File: <strong>IdGeneratorRequestProcessor.java</strong><br>
 * Created: <strong>28 Jan 2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Server Standalone v0.1-alpha
 */
public class IdGeneratorRequestProcessor implements ObjectProcessor<IdGeneratorRequest> {

	private static final long ID_RANGE = 2;

	@Override
	public Class<IdGeneratorRequest> getInputClass() { return IdGeneratorRequest.class; }

	@Override
	public void process(IdGeneratorRequest input, long socketId, ObjectWriteProxy writeProxy) throws IOException {
		System.out.println("Received id generation request.");

		ConfigItem	currentId	= PersistenceManager.getPersistenceManager().getConfigItemById("currentMessageId");
		IdGenerator	generator	= new IdGenerator(Integer.parseInt(currentId.getValue()), ID_RANGE);
		currentId.setValue(String.valueOf(Integer.parseInt(currentId.getValue()) + ID_RANGE));
		PersistenceManager.getPersistenceManager().updateConfigItem(currentId);

		System.out.println("Sending new id generator " + generator);
		writeProxy.write(socketId, generator);
	}
}
